==> kbarcode-trinity-3.5.13.2.tar.xz: kbarcode-trinity-3.5.13.2/kbarcode/smalldialogs.h <==
/***************************************************************************
                          smalldialogs.h  -  description
                             -------------------
    begin                : Son Jul 20 2003
    copyright            : (C) 2003 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SMALLDIALOGS_H
#define SMALLDIALOGS_H

#include <tqwidget.h>
#include <kdialogbase.h>

class KCompletion;
class KIntNumInput;
class KLineEdit;

namespace DSSmallDialogs {

    class AddAllDialog : public KDialogBase {
        Q_OBJECT
  TQ_OBJECT
        public:
            AddAllDialog(TQWidget *parent=0, const char *name=0);

            TQString groupName() const;
            int numberLabels() const;

        protected:
            KLineEdit* group;
            KIntNumInput* number;
    };

    class AddItemsDialog : public KDialogBase {
        Q_OBJECT
  TQ_OBJECT
        public:
            AddItemsDialog( TQWidget* parent = 0, const char* name = 0 );
            AddItemsDialog( const TQString & a, const TQString & g, int c, TQWidget* parent = 0, const char* name = 0 );

            void setGroupCompletion( KCompletion* c );

            int count() const;
            const TQString articleNo() const;
            const TQString groupName() const;
            
        signals:
            void add( const TQString & article, const TQString & group, int count);

        private slots:
            void setupSql();

        protected:
            KLineEdit* article;
            KLineEdit* group;
            KIntNumInput* number;

            void slotUser1();
            void init();
    };

}

#endif

==> kbarcode-trinity-14.0.12.tar.xz: kbarcode-trinity-14.0.12/kbarcode/smalldialogs.h <==
/***************************************************************************
                          smalldialogs.h  -  description
                             -------------------
    begin                : Son Jul 20 2003
    copyright            : (C) 2003 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SMALLDIALOGS_H
#define SMALLDIALOGS_H

#include <tqwidget.h>
#include <kdialogbase.h>

class TDECompletion;
class KIntNumInput;
class KLineEdit;

namespace DSSmallDialogs {

    class AddAllDialog : public KDialogBase {
        Q_OBJECT
  
        public:
            AddAllDialog(TQWidget *parent=0, const char *name=0);

            TQString groupName() const;
            int numberLabels() const;

        protected:
            KLineEdit* group;
            KIntNumInput* number;
    };

    class AddItemsDialog : public KDialogBase {
        Q_OBJECT
  
        public:
            AddItemsDialog( TQWidget* parent = 0, const char* name = 0 );
            AddItemsDialog( const TQString & a, const TQString & g, int c, TQWidget* parent = 0, const char* name = 0 );

            void setGroupCompletion( TDECompletion* c );

            int count() const;
            const TQString articleNo() const;
            const TQString groupName() const;
            
        signals:
            void add( const TQString & article, const TQString & group, int count);

        private slots:
            void setupSql();

        protected:
            KLineEdit* article;
            KLineEdit* group;
            KIntNumInput* number;

            void slotUser1();
            void init();
    };

}

#endif
